@@ -118,30 +118,34 @@ def decompose(data, period=365, model='additive'):
         period (int, optional): Seasonal interval. Defaults to 365.
         model (str, optional): Additive or multiplicative. Defaults to 'additive'.
     """
-    decomposition = seasonal_decompose(data, model=model, period=period)
+    try:
+        decomposition = seasonal_decompose(data, model=model, period=period)
 
-    plt.figure(figsize=(15, 8))
-    plt.subplot(4, 1, 1)
-    plt.plot(decomposition.observed)
-    plt.xlabel('Date')
-    plt.ylabel("Real values")
+        plt.figure(figsize=(15, 8))
+        plt.subplot(4, 1, 1)
+        plt.plot(decomposition.observed)
+        plt.xlabel('Date')
+        plt.ylabel("Real values")
 
-    plt.subplot(4, 1, 2)
-    plt.plot(decomposition.trend)
-    plt.xlabel('Date')
-    plt.ylabel("Trend")
+        plt.subplot(4, 1, 2)
+        plt.plot(decomposition.trend)
+        plt.xlabel('Date')
+        plt.ylabel("Trend")
 
-    plt.subplot(4, 1, 3)
-    plt.plot(decomposition.seasonal)
-    plt.xlabel('Date')
-    plt.ylabel("Seasonality")
+        plt.subplot(4, 1, 3)
+        plt.plot(decomposition.seasonal)
+        plt.xlabel('Date')
+        plt.ylabel("Seasonality")
 
-    plt.subplot(4, 1, 4)
-    plt.plot(decomposition.resid)
-    plt.xlabel('Date')
-    plt.ylabel("Residuals")
+        plt.subplot(4, 1, 4)
+        plt.plot(decomposition.resid)
+        plt.xlabel('Date')
+        plt.ylabel("Residuals")
 
-    plt.suptitle("Seasonal decomposition", fontsize=20)
-    plt.subplots_adjust(top=0.88)
+        plt.suptitle("Seasonal decomposition", fontsize=20)
+        plt.subplots_adjust(top=0.88)
 
-    plt.show()
+        plt.show()
+
+    except ValueError:
+        misc.traceback_warning("Number of samples is probably too low to compute.")
