@@ -36,8 +36,6 @@ To see all the possible values, use
     >>> predictit.configuration.print_config()
 '''
 
-import predictit
-
 
 class config():
 
@@ -65,12 +63,11 @@ class config():
     predicted_column = ''  # Name of predicted column (for dataframe data) or it's index - string or int.
     predicted_columns = []  # For predict_multiple function only! List of names of predicted columns or it's indexes. If 'data' is dataframe or numpy, then you can use ['*'] to predict all the columns with numbers.
 
+    datetime_index = ''  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
     freq = 0  # Interval for predictions 'M' - months, 'D' - Days, 'H' - Hours.
     freqs = []  # For predict_multiple function only! List of intervals of predictions 'M' - months, 'D' - Days, 'H' - Hours. Default use [].
     resample_function = 'sum'  # 'sum' or 'mean' depends of data. For example if current in technological process - mean, if units sold, then sum.
 
-    datetime_index = ''  # Index of dataframe datetime column or it's name if it has datetime column. If there already is index in input data, it will be used automatically. Data are sorted by time.
-
     datalength = 0  # The length of the data used for prediction (after resampling). If 0, than full length.
     max_imported_length = 0  # Max length of imported samples (before resampling). If 0, than full length.
 
@@ -80,7 +77,7 @@ class config():
 
     return_type = 'best'  # 'best', 'all_dataframe', 'detailed_dictionary' or 'models_error_criterion'.
     # 'best' return array of predictions, 'all_dataframe' return results and models names in columns. 'detailed_dictionary' is used for GUI
-    # and return results as best result, all results, string div with plot and more. 'models_error_criterion' returns MAPE, RMSE or DWT(based on config) criterion of all models in array.
+    # and return results as best result, all results dataframe, dataframe for plot, string div with plot and more. 'models_error_criterion' returns MAPE, RMSE or DWT(based on config) criterion of all models in array.
 
     debug = 1  # Debug - If 1, print all results and all the warnings and errors on the way, if 2, stop on first warning, if -1 do not print anything, just return result.
 
@@ -121,17 +118,17 @@ class config():
     default_n_steps_in = 30  # How many lagged values are in vector input to model.
     other_columns = 1  # If use other columns. Bool.
     default_other_columns_length = 2  # Other columns vector length used for predictions. If None, lengths same as predicted columnd. If 0, other columns are not used for prediction.
-    remove_nans = 'any_columns'  # 'any_columns' will remove all the columns where is at least one nan column. 'any_rows' delete each row, here is nan value
+    remove_nans = 'any_columns'  # 'any_columns' will remove all the columns where is at least one nan column. 'any_rows' delete each row, where is nan value
     dtype = 'float32'  # Main dtype used in prediction. 'float32' or 'float64'.
     repeatit = 50  # How many times is computation repeated for error criterion evaluation.
 
     data_transform = 0  # 'difference' or 0 - Transform the data on differences between two neighbor values.
     analyzeit = 0  # If 1, analyze original data, if 2 analyze preprocessed data, if 3, then both. Statistical distribution, autocorrelation, seasonal decomposition etc.
     analyze_seasonal_decompose = {'period': 365, 'model': 'additive'}  # Parameters for seasonal decompose in analyze. Find if there are periodically repeating patterns in data.
-    standardizeit = 0  # 'standardize'  # One from None, 'standardize', '-11', '01', 'robust'.
+    standardizeit = 'standardize'  # 'standardize'  # One from None, 'standardize', '-11', '01', 'robust'.
 
     evaluate_type = 'original'  # 'original' or 'preprocessed'. Define whether error criterion (e.g. RMSE) is evaluated on preprocessed data or on original data.
-    smoothit = (11, 2)  # Smoothing data with Savitzky-Golay filter. First argument is window and second is polynomial order. If 0, not smoothing.
+    smoothit = (11, 2)  # Smoothing data with Savitzky-Golay filter. First argument is window (must be odd!) and second is polynomial order. If 0, not smoothing.
     power_transformed = 0  # Whether transform results to have same standard deviation and mean as train data.
     remove_outliers = 0  # Remove extraordinary values. Value is threshold for ignored values. Value means how many times standard deviation from the average threshold is far (have to be > 3, else delete most of data). If predicting anomalies, use 0.
     error_criterion = 'mse_sklearn'  # 'mse_sklearn', 'mape' or 'rmse' or 'dtw' (dynamic time warping).
@@ -162,32 +159,33 @@ class config():
 
     # For more info about models parameters, check it's docstrings or run e.g. `help(predictit.models.sklearn_regression)` in your debug or interactive console
 
-    used_models = {
+    used_models = [
 
-        **{model_name: predictit.models.statsmodels_autoregressive for model_name in [
-            'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg',
-            'SARIMAX (Seasonal ARIMA)'
-        ]},
+        # predictit.models.statsmodels_autoregressive
+        'AR (Autoregression)', 'ARMA', 'ARIMA (Autoregression integrated moving average)', 'autoreg', 'SARIMAX (Seasonal ARIMA)',
 
-        **{model_name: predictit.models.autoreg_LNU for model_name in [
-            'Autoregressive Linear neural unit', 'Autoregressive Linear neural unit normalized']},  # , 'Linear neural unit with weigths predict'
+        #predictit.models.autoreg_LNU
+        'Autoregressive Linear neural unit', 'Autoregressive Linear neural unit normalized',
+        # , 'Linear neural unit with weigths predict'
 
-        'Conjugate gradient': predictit.models.conjugate_gradient,
+        # predictit.models.conjugate_gradient
+        'Conjugate gradient',
 
-        ### 'tensorflow_lstm': predictit.models.tensorflow,
-        ### 'tensorflow_mlp': predictit.models.tensorflow,
+        # predictit.models.tensorflow
+        ### 'tensorflow_lstm'
+        ### 'tensorflow_mlp'
 
-        **{model_name: predictit.models.sklearn_regression for model_name in [
-            'Sklearn regression', 'Bayes ridge regression', 'Passive aggressive regression', 'Gradient boosting',
-            'KNeighbors regression', 'Decision tree regression', 'Hubber regression',
-            # 'Bagging regression', 'Stochastic gradient regression', 'Extreme learning machine', 'Gen Extreme learning machine',  'Extra trees regression', 'Random forest regression'
+        # predictit.models.sklearn_regression
+        'Sklearn regression', 'Bayes ridge regression', 'Passive aggressive regression', 'Gradient boosting',
+        'KNeighbors regression', 'Decision tree regression', 'Hubber regression',
+        # 'Bagging regression', 'Stochastic gradient regression', 'Extreme learning machine', 'Gen Extreme learning machine',  'Extra trees regression', 'Random forest regression'
 
-            'Sklearn regression one step', 'Bayes ridge regression one step', 'Decision tree regression one step',
-            'Hubber regression one step',
-        ]},
+        'Sklearn regression one step', 'Bayes ridge regression one step', 'Decision tree regression one step',
+        'Hubber regression one step',
 
-        'Compare with average': predictit.models.compare_with_average
-    }
+        # predictit.models.compare_with_average
+        'Compare with average'
+    ]
 
     input_types = None
 
@@ -312,6 +310,9 @@ class config():
     units = [1, 100]
     order = [0, 20]
     maxorder = 20
+
+    # You can use function to get all models in list and then optimization to find the best one
+    # import predictit
     regressors = 'linear'  # predictit.models.sklearn_regression.get_regressors(
 
     models_parameters_limits = None
@@ -401,38 +402,23 @@ class config():
             'other_columns': 0, 'data_transform': 0, 'remove_outliers': 0, 'analyzeit': 0, 'standardizeit': None,
 
             # If editting or adding new models, name of the models have to be the same as in models module
-            'used_models': {
-                'AR (Autoregression)': predictit.models.statsmodels_autoregressive,
-                'Conjugate gradient': predictit.models.conjugate_gradient,
-                'Sklearn regression': predictit.models.sklearn_regression,
-                'Compare with average': predictit.models.compare_with_average
-            },
+            'used_models': ['AR (Autoregression)', 'Conjugate gradient', 'Sklearn regression', 'Compare with average'],
         },
 
         'normal': {
             'optimizeit': 0, 'default_n_steps_in': 15, 'repeatit': 50, 'optimization': 0, 'datalength': 3000,
             'other_columns': 1, 'remove_outliers': 0, 'analyzeit': 0, 'standardizeit': 'standardize',
 
-            'used_models': {
+            'used_models': [
+                'AR (Autoregression)', 'ARIMA (Autoregression integrated moving average)', 'autoreg', 'SARIMAX (Seasonal ARIMA)',
 
-                **{model_name: predictit.models.statsmodels_autoregressive for model_name in [
-                    'AR (Autoregression)', 'ARIMA (Autoregression integrated moving average)', 'autoreg', 'SARIMAX (Seasonal ARIMA)']},
+                'Autoregressive Linear neural unit', 'Conjugate gradient',
 
-                'Autoregressive Linear neural unit': predictit.models.autoreg_LNU,
-                # 'Linear neural unit with weigths predict': predictit.models.autoreg_LNU,
-                'Conjugate gradient': predictit.models.conjugate_gradient,
+                'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Decision tree regression',
+                'KNeighbors regression', 'Random forest regression', 'Bagging regression',
 
-                # # 'tensorflow_lstm': predictit.models.tensorflow,
-                # # 'tensorflow_mlp': predictit.models.tensorflow,
+                'Compare with average']
 
-                **{model_name: predictit.models.sklearn_regression for model_name in [
-                    'Sklearn regression', 'Bayes ridge regression', 'Hubber regression', 'Decision tree regression',
-                    'KNeighbors regression', 'Random forest regression', 'Bagging regression',
-                    # 'Passive aggressive regression', 'Extreme learning machine', 'Gen Extreme learning machine', 'Gradient boosting'
-                ]},
-
-                'Compare with average': predictit.models.compare_with_average
-            },
         }
     }
 
